@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
 @Author: HuangJianYi
-@Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-09-27 18:17:08
+@Date: 2022-04-24 15:15:19
+@LastEditTime: 2022-10-20 17:03:53
 @LastEditors: HuangJianYi
-@Description: 公共handler模块
+@Description: 
 """
 
 import ast
@@ -18,15 +18,17 @@ from urllib.parse import parse_qs, urlparse
 
 from seven_framework.redis import *
 from seven_framework.web_tornado.base_handler.base_api_handler import *
+
+from seven_cloudapp_frame.handlers.filter_base import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.libs.customize.cryptography_helper import *
 from seven_cloudapp_frame.libs.customize.riskmanage_helper import *
 from seven_cloudapp_frame.models.seven_model import *
+from seven_cloudapp_frame.models.operate_base_model import *
 from seven_cloudapp_frame.models.user_base_model import *
 from seven_cloudapp_frame.models.db_models.app.app_info_model import *
 from seven_cloudapp_frame.models.db_models.act.act_info_model import *
 from seven_cloudapp_frame.models.db_models.operation.operation_log_model import *
-from seven_cloudapp_frame.handlers.filter_base import *
 
 
 class FrameBaseHandler(BaseApiHandler):
@@ -469,9 +471,14 @@ class FrameBaseHandler(BaseApiHandler):
                 if user_nick:
                     store_user_nick = user_nick.split(':')[0]
                     if store_user_nick:
-                        app_info_dict = AppInfoModel(context=self).get_cache_dict(where="store_user_nick=%s", limit="0,1", field="app_id", params=store_user_nick)
+                        main_user_open_id = self.get_param("main_user_open_id")
+                        app_info_model = AppInfoModel(context=self)
+                        app_info_dict = app_info_model.get_cache_dict(where="store_user_nick=%s", limit="0,1", field="app_id", params=store_user_nick)
                         if app_info_dict:
                             app_id = app_info_dict["app_id"]
+                            if main_user_open_id !="" and app_info_dict.get("main_user_open_id","") == "":
+                                app_info_model.update_table("main_user_open_id=%s","app_id=%s",params=[main_user_open_id,app_id])
+                                app_info_model.delete_dependency_key()
             elif self._request_source_type() == 1:
                 app_id = self.get_param("source_app_id")
                 #淘宝小程序 在IDE上返回前端模板id，无论哪个环境
@@ -511,56 +518,33 @@ class FrameBaseHandler(BaseApiHandler):
             act_id = config_act_id
         return act_id
 
-    def create_operation_log(self, operation_type=1, model_name="", handler_name="", old_detail=None, update_detail=None, operate_user_id="", operate_user_name="", operate_role_id="", title="", desc=""):
+    def create_operation_log(self, operation_type=1, model_name="", handler_name="", old_detail=None, update_detail=None, operate_user_id="", operate_user_name="", operate_role_id="", title="", operation_desc=""):
         """
         :description: 创建操作日志
-        :param operation_type：操作类型：1-add，2-update，3-delete，4-review，5-copy
-        :param model_name：模块或表名称
+        :param operation_type：操作类型（查看枚举类OperationType）
+        :param model_name：模块或表名称（跟配置表对应）
         :param handler_name：handler名称
-        :param old_detail：当前对象
-        :param update_detail：更新之后的对象
+        :param old_detail：变更前对象
+        :param update_detail：变更后对象
         :param operate_user_id：操作人标识
         :param operate_user_name：操作人名称
         :param operate_role_id：操作人角色标识
-        :param title：标题
-        :param desc：描述
+        :param title：标题(对象)
+        :param operation_desc：描述
+        :param operation_ways：操作方式(1单一操作2批量操作)
         :return: 
         :last_editors: HuangJianYi
         """
-        operation_log = OperationLog()
-        operation_log_model = OperationLogModel(context=self)
-
-        operation_log.app_id = self.get_app_id()
-        operation_log.act_id = self.get_act_id()
-        operation_log.open_id = self.get_open_id()
-        operation_log.user_nick = self.get_user_nick()
-        operation_log.request_params = self.request_params
-        operation_log.method = self.request.method
-        operation_log.protocol = self.request.protocol
-        operation_log.request_host = self.request.host
-        operation_log.request_uri = self.request.uri
-        operation_log.remote_ip = self.get_remote_ip()
-        operation_log.operation_type = operation_type
-        operation_log.model_name = model_name
-        operation_log.handler_name = handler_name
-        operation_log.detail = old_detail if old_detail else {}
-        operation_log.update_detail = update_detail if update_detail else {}
-        operation_log.operate_user_id = operate_user_id
-        operation_log.operate_user_name = operate_user_name
-        operation_log.operate_role_id = operate_role_id
-        operation_log.title = title
-        operation_log.desc = desc
-        operation_log.create_date = TimeHelper.get_now_format_time()
-        operation_log.create_day = SevenHelper.get_now_day_int()
-
-        if isinstance(operation_log.request_params, dict):
-            operation_log.request_params = self.json_dumps(operation_log.request_params)
-        if isinstance(old_detail, dict):
-            operation_log.detail = self.json_dumps(old_detail)
-        if isinstance(update_detail, dict):
-            operation_log.update_detail = self.json_dumps(update_detail)
-
-        operation_log_model.add_entity(operation_log)
+        plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
+        if plat_type == 1:
+            if not operate_user_id:
+                operate_user_id = self.get_open_id()
+            if not operate_user_name:
+                operate_user_name = self.get_user_nick()
+        if not handler_name:
+            handler_name = self.__class__.__name__
+        operate_base_model = OperateBaseModel(context=self)
+        operate_base_model.add_operation_log(operation_type, title, operation_desc, model_name, handler_name, old_detail, update_detail, self.get_app_id(), self.get_act_id(), operate_user_id, operate_user_name, operate_role_id, {"request_params": self.request_params, "request": self.request}, self.get_remote_ip())
 
     def check_continue_request(self, handler_name, app_id, object_id, expire=100):
         """
