@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 11:03:56
-@LastEditTime: 2022-06-14 17:53:00
+@LastEditTime: 2022-10-19 15:13:30
 @LastEditors: HuangJianYi
 @Description: ip模块
 """
@@ -28,6 +28,8 @@ class SaveIpInfoHandler(ClientBaseHandler):
         :param show_pic：展示图片
         :param sort_index：排序
         :param is_release：是否发布
+        :param mode_type：模式类型
+        :param ip_config_json：ip配置
         :return: response_json_success
         :last_editors: HuangJianYi
         """
@@ -40,6 +42,8 @@ class SaveIpInfoHandler(ClientBaseHandler):
         sort_index = int(self.get_param("sort_index", 0))
         is_release = int(self.get_param("is_release", 1))
         ip_type = int(self.get_param("ip_type", 0))
+        mode_type = int(self.get_param("mode_type", 0))
+        ip_config_json = self.get_param("ip_config_json")
         ip_summary = self.get_param("ip_summary")
 
         invoke_result_data = self.business_process_executing()
@@ -47,14 +51,14 @@ class SaveIpInfoHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
 
         ip_base_model = IpBaseModel(context=self)
-        invoke_result_data = ip_base_model.save_ip_info(app_id, act_id, ip_id, ip_name, ip_pic, show_pic, sort_index, is_release, ip_type, ip_summary)
+        invoke_result_data = ip_base_model.save_ip_info(app_id, act_id, ip_id, ip_name, ip_pic, show_pic, sort_index, is_release, ip_type, ip_summary, mode_type, ip_config_json)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveIpInfoHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
+            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title=ip_name)
         else:
-            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveIpInfoHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
+            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=ip_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -120,10 +124,10 @@ class DeleteIpInfoHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ip_base_model = IpBaseModel(context=self)
-        invoke_result_data = ip_base_model.update_ip_info_status(app_id, ip_id,1)
+        invoke_result_data = ip_base_model.update_ip_info_status(app_id, ip_id, 1)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(OperationType.delete.value, "ip_info_tb", "DeleteIpInfoHandler", None, ip_id)
+        self.create_operation_log(operation_type=OperationType.delete.value, model_name="ip_info_tb", title=invoke_result_data.data["ip_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -156,6 +160,8 @@ class ReleaseIpInfoHandler(ClientBaseHandler):
         invoke_result_data = ip_base_model.release_ip_info(app_id, ip_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
+        self.create_operation_log(operation_type=operation_type, model_name="ip_info_tb", title=invoke_result_data.data["ip_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -175,6 +181,7 @@ class SaveIpTypeHandler(ClientBaseHandler):
         :param act_id：活动标识
         :param ip_type_id: ip类型标识
         :param type_name：类型名称
+        :param type_pic：类型图片
         :param sort_index：排序
         :param is_release：是否发布
         :return: response_json_success
@@ -184,6 +191,7 @@ class SaveIpTypeHandler(ClientBaseHandler):
         act_id = self.get_act_id()
         ip_type_id = self.get_param_int("ip_type_id", 0)
         type_name = self.get_param("type_name")
+        type_pic = self.get_param("type_pic")
         sort_index = self.get_param_int("sort_index", 0)
         is_release = self.get_param_int("is_release", 1)
 
@@ -192,14 +200,14 @@ class SaveIpTypeHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
 
         ip_base_model = IpBaseModel(context=self)
-        invoke_result_data = ip_base_model.save_ip_type(app_id, act_id, ip_type_id, type_name, sort_index, is_release)
+        invoke_result_data = ip_base_model.save_ip_type(app_id, act_id, ip_type_id, type_name, sort_index, is_release, type_pic)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveIpTypeHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
+            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title=type_name)
         else:
-            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveIpTypeHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
+            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=type_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -268,6 +276,8 @@ class ReleaseIpTypeHandler(ClientBaseHandler):
         invoke_result_data = ip_base_model.release_ip_type(app_id, ip_type_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
+        self.create_operation_log(operation_type=operation_type, model_name="ip_type_tb", title=invoke_result_data.data["type_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
