@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2022-09-27 18:40:38
+@LastEditTime: 2022-10-17 14:16:15
 @LastEditors: HuangJianYi
 @Description: 小活动模块（机台）
 """
@@ -88,9 +88,9 @@ class SaveActModuleHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveActModuleHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
+            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title=module_name)
         else:
-            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveActModuleHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
+            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=module_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -198,7 +198,7 @@ class DeleteActModuleHandler(ClientBaseHandler):
         invoke_result_data = module_base_model.update_act_module_status(app_id, module_id, 1)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(OperationType.delete.value, "act_module_tb", "DeleteActModuleHandler", None, module_id)
+        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_module_tb", title=invoke_result_data.data["module_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success ==False:
@@ -228,7 +228,7 @@ class ReviewActModuleHandler(ClientBaseHandler):
         invoke_result_data = module_base_model.update_act_module_status(app_id, module_id, 0)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(OperationType.review.value, "act_module_tb", "ReviewActModuleHandler", None, module_id)
+        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_module_tb", title=invoke_result_data.data["module_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success ==False:
@@ -260,6 +260,8 @@ class ReleaseActModuleHandler(ClientBaseHandler):
         invoke_result_data = module_base_model.release_act_module(app_id, module_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
+        self.create_operation_log(operation_type=operation_type, model_name="act_module_tb", title=invoke_result_data.data["module_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success ==False:
