@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2022-06-14 14:42:56
+@LastEditTime: 2022-10-17 18:59:40
 @LastEditors: HuangJianYi
 @Description: 订单模块
 """
@@ -217,6 +217,8 @@ class UpdatePrizeOrderSellerRemarkHandler(ClientBaseHandler):
         invoke_result_data = order_base_model.update_prize_order_seller_remark(app_id, act_id, prize_order_id, seller_remark)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        title = "修改订单备注；用户昵称：" + invoke_result_data.data["user_nick"] + "，openid：" + invoke_result_data.data["open_id"]
+        self.create_operation_log(operation_type=OperationType.operate.value, model_name="prize_order_tb", title=title)
         return self.response_json_success()
 
 
@@ -254,6 +256,13 @@ class UpdatePrizeOrderStatusHandler(ClientBaseHandler):
         invoke_result_data = order_base_model.update_prize_order_status(app_id, act_id, prize_order_id, order_status, express_company, express_no, prize_roster_sub_table)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        title = "修改订单状态；"
+        if order_status == 1:
+            title = "发货；"
+        elif  order_status == 2:
+            title = "不予发货；"
+        title = title + "用户昵称：" + invoke_result_data.data["user_nick"] + "，openid：" + invoke_result_data.data["open_id"]
+        self.create_operation_log(operation_type=OperationType.operate.value, model_name="prize_order_tb", title=title)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success ==False:
@@ -289,10 +298,12 @@ class ImportPrizeOrderHandler(ClientBaseHandler):
         if not invoke_result_data.data:
             invoke_result_data.data = {}
         prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
+        menu_name = invoke_result_data.data["menu_name"] if invoke_result_data.data.__contains__("menu_name") else "发货列表"
         order_base_model = OrderBaseModel(context=self)
         invoke_result_data = order_base_model.import_prize_order(app_id, act_id, content_type, content, ref_head_name, prize_roster_sub_table)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        self.create_operation_log(operation_type=OperationType.import_data.value, model_name="prize_order_tb", title=menu_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success ==False:
@@ -348,6 +359,7 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        menu_name = invoke_result_data.data["menu_name"] if invoke_result_data.data.__contains__("menu_name") else "发货列表"
         prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
 
         order_base_model = OrderBaseModel(context=self)
@@ -367,6 +379,7 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         ref_params = {}
         result_data = self.business_process_executed(prize_order_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
+        self.create_operation_log(operation_type=OperationType.export.value, model_name="prize_order_tb", title=menu_name)
         return self.response_json_success(resource_path)
 
     def business_process_executed(self, result_data,ref_params):
@@ -462,6 +475,7 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        menu_name = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("menu_name") else "中奖记录列表"
 
         order_base_model = OrderBaseModel(context=self)
         prize_roster_list_dict = []
@@ -479,6 +493,7 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         ref_params = {}
         result_data = self.business_process_executed(prize_roster_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
+        self.create_operation_log(operation_type=OperationType.export.value, model_name="prize_roster_tb", title=menu_name)
         return self.response_json_success(resource_path)
 
     def business_process_executed(self, result_data, ref_params):
@@ -552,6 +567,7 @@ class TaoPayOrderExportHandler(ClientBaseHandler):
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        menu_name = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("menu_name") else "支付订单列表"
 
         if main_pay_order_no:
             condition += " and " if condition else ""
@@ -579,6 +595,7 @@ class TaoPayOrderExportHandler(ClientBaseHandler):
         ref_params = {}
         result_data = self.business_process_executed(tao_pay_order_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
+        self.create_operation_log(operation_type=OperationType.export.value, model_name="tao_pay_order_tb", title=menu_name)
         return self.response_json_success(resource_path)
 
     def business_process_executed(self, result_data, ref_params):
@@ -602,4 +619,3 @@ class TaoPayOrderExportHandler(ClientBaseHandler):
             data_row["支付时间"] = TimeHelper.datetime_to_format_time(tao_pay_order_dict["pay_date"])
             result_list.append(data_row)
         return result_list
-
