@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2022-06-13 14:38:04
+@LastEditTime: 2022-10-17 14:47:19
 @LastEditors: HuangJianYi
 @Description: 奖品模块
 """
@@ -117,9 +117,9 @@ class SaveActPrizeHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveActPrizeHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
+            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title=prize_name)
         else:
-            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveActPrizeHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
+            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=prize_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -192,7 +192,7 @@ class DeleteActPrizeHandler(ClientBaseHandler):
         invoke_result_data = prize_base_model.update_act_prize_status(app_id, prize_id, 1)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(OperationType.delete.value, "act_prize_tb", "DeleteActPrizeHandler", None, prize_id)
+        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_prize_tb", title=invoke_result_data.data["prize_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -222,7 +222,7 @@ class ReviewActPrizeHandler(ClientBaseHandler):
         invoke_result_data = prize_base_model.update_act_prize_status(app_id, prize_id, 0)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(OperationType.review.value, "act_prize_tb", "ReviewActPrizeHandler", None, prize_id)
+        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_prize_tb", title=invoke_result_data.data["prize_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -254,6 +254,8 @@ class ReleaseActPrizeHandler(ClientBaseHandler):
         invoke_result_data = prize_base_model.release_act_prize(app_id, prize_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
+        self.create_operation_log(operation_type=operation_type, model_name="act_prize_tb", title=invoke_result_data.data["prize_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -295,6 +297,7 @@ class ActPrizeExportHandler(ClientBaseHandler):
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        menu_name = invoke_result_data.data["menu_name"] if invoke_result_data.data.__contains__("menu_name") else "奖品列表"
 
         prize_base_model = PrizeBaseModel(context=self)
         act_prize_list_dict = []
@@ -312,6 +315,7 @@ class ActPrizeExportHandler(ClientBaseHandler):
         ref_params = {}
         result_data = self.business_process_executed(act_prize_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
+        self.create_operation_log(operation_type=OperationType.export.value, model_name="act_prize_tb", title=menu_name)
         return self.response_json_success(resource_path)
 
     def business_process_executed(self, result_data, ref_params):
