@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-10 10:05:38
-@LastEditTime: 2022-07-14 09:53:02
+@LastEditTime: 2022-10-20 17:15:10
 @LastEditors: HuangJianYi
 @Description: 任务模块
 """
@@ -57,6 +57,17 @@ class SaveTaskInfoHandler(ClientBaseHandler):
         act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         task_list = self.get_param("task_list")
+
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else ""
+        operate_user_id = invoke_result_data.data["operate_user_id"] if invoke_result_data.data.__contains__("operate_user_id") else ""
+        operate_user_name = invoke_result_data.data["operate_user_name"] if invoke_result_data.data.__contains__("operate_user_name") else ""
+        operate_role_id = invoke_result_data.data["operate_role_id"] if invoke_result_data.data.__contains__("operate_role_id") else ""
+
         try:
             task_list = SevenHelper.json_loads(task_list)
         except Exception as ex:
@@ -71,6 +82,7 @@ class SaveTaskInfoHandler(ClientBaseHandler):
             sort_index = int(item["sort_index"]) if item.__contains__("sort_index") else 0
             is_release = int(item["is_release"]) if item.__contains__("is_release") else 0
             config_json = SevenHelper.json_dumps(item["config_json"]) if item.__contains__("config_json") else {}
+            title = title_prefix + ";" + task_name if title_prefix else task_name
             if "id" in item.keys():
                 task_info = task_info_model.get_entity_by_id(int(item["id"]))
                 if task_info:
@@ -84,7 +96,7 @@ class SaveTaskInfoHandler(ClientBaseHandler):
                     task_info.modify_date = SevenHelper.get_now_datetime()
                     task_info_model.update_entity(task_info, "complete_type,task_name,sort_index,is_release,config_json,modify_date")
                     task_base_model._delete_task_info_dependency_key(0,task_info.id)
-                    self.create_operation_log(OperationType.update.value, task_info.__str__(), "SaveTaskInfoHandler", SevenHelper.json_dumps(old_task_info.__dict__), SevenHelper.json_dumps(task_info.__dict__))
+                    self.create_operation_log(operation_type=OperationType.update.value, model_name=task_info.__str__(), old_detail=old_task_info.__dict__, update_detail=task_info.__dict__, title=title, operate_user_id=operate_user_id, operate_user_name=operate_user_name, operate_role_id=operate_role_id)
                     ref_params = {}
                     self.business_process_executed(task_info, ref_params)
             else:
@@ -101,7 +113,7 @@ class SaveTaskInfoHandler(ClientBaseHandler):
                 task_info.create_date = SevenHelper.get_now_datetime()
                 task_info.modify_date = SevenHelper.get_now_datetime()
                 task_info_model.add_entity(task_info)
-                self.create_operation_log(OperationType.add.value, task_info.__str__(), "SaveTaskInfoHandler", None, SevenHelper.json_dumps(task_info))
+                self.create_operation_log(operation_type=OperationType.add.value, model_name=task_info.__str__(), old_detail=None, update_detail=task_info.__dict__, title=title, operate_user_id=operate_user_id, operate_user_name=operate_user_name, operate_role_id=operate_role_id)
                 ref_params = {}
                 self.business_process_executed(task_info, ref_params)
 
