@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2022-06-14 16:46:28
+@LastEditTime: 2022-10-17 18:57:31
 @LastEditors: HuangJianYi
 @Description: 用户模块
 """
@@ -95,6 +95,13 @@ class UpdateUserStatusHandler(ClientBaseHandler):
         invoke_result_data = user_base_model.update_user_state(app_id, act_id, user_id, user_state)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+        title = "更新用户状态；"
+        if user_state == 0:
+            title = "解锁用户；"
+        else:
+            title = "拉黑用户；"
+        title = title + "用户昵称：" + invoke_result_data.data["user_nick"] + "，openid：" + invoke_result_data.data["open_id"]
+        self.create_operation_log(operation_type=OperationType.operate.value, model_name="user_info_tb", title=title)
         return self.response_json_success()
 
 
@@ -122,6 +129,8 @@ class UpdateUserStatusByBlackHandler(ClientBaseHandler):
         invoke_result_data = user_base_model.update_user_state_by_black(app_id, act_id, user_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+        title = "拉黑用户；用户昵称：" + invoke_result_data.data["user_nick"] + "，openid：" + invoke_result_data.data["open_id"]
+        self.create_operation_log(operation_type=OperationType.operate.value, model_name="user_info_tb", title=title)
         ref_params = {}
         self.business_process_executed(invoke_result_data, ref_params)
         return self.response_json_success()
@@ -153,6 +162,13 @@ class AuditUserBlackHandler(ClientBaseHandler):
         invoke_result_data = user_base_model.audit_user_black(app_id, black_id, audit_status, audit_remark)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+        title = "操作审核黑名单；"
+        if audit_status == 2:
+            title = "同意解锁用户；"
+        elif audit_status == 3:
+            title = "拒绝解锁用户；"
+        title = title + "用户昵称：" + invoke_result_data.data["user_info"]["user_nick"] + "，openid：" + invoke_result_data.data["user_info"]["open_id"]
+        self.create_operation_log(operation_type=OperationType.operate.value, model_name="user_black_tb", title=title)
         ref_params = {}
         self.business_process_executed(invoke_result_data, ref_params)
         return self.response_json_success()
@@ -178,6 +194,8 @@ class UpdateAuditRemarkHandler(ClientBaseHandler):
         invoke_result_data = user_base_model.update_audit_remark(app_id, black_id, audit_remark)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        title = "修改黑名单审核备注；用户昵称：" + invoke_result_data.data["user_black"]["user_nick"] + "，openid：" + invoke_result_data.data["user_black"]["open_id"]
+        self.create_operation_log(operation_type=OperationType.operate.value, model_name="user_black_tb", title=title)
         return self.response_json_success()
 
 
@@ -253,6 +271,15 @@ class UpdateUserAssetHandler(ClientBaseHandler):
         invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], asset_type, asset_value, asset_object_id, 3, "", "手动配置", "手动配置")
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+        title = "资产配置；"
+        if asset_type == 1:
+            title = "次数配置；"
+        elif asset_type == 2:
+            title = "积分配置；"
+        elif asset_type == 3:
+            title = "价格档位配置；"
+        title = title + "用户昵称：" + user_info_dict["user_nick"] + "，openid：" + user_info_dict["open_id"]
+        self.create_operation_log(operation_type=OperationType.operate.value, model_name="user_asset_tb", title=title)
         ref_params = {}
         self.business_process_executed(invoke_result_data, ref_params)
         return self.response_json_success()
@@ -295,7 +322,8 @@ class BatchUpdateUserAssetHandler(ClientBaseHandler):
                 if asset_object_ids:
                     asset_object_ids += ","
                 asset_object_ids += asset_object["asset_object_id"]
-
+        title = "批量变更资产配置；用户昵称：" + user_info_dict["user_nick"] + "，openid：" + user_info_dict["open_id"]
+        self.create_operation_log(operation_type=OperationType.operate.value, model_name="user_asset_tb", title=title)
         return self.response_json_success()
 
 
