@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-09-26 10:18:59
+@LastEditTime: 2022-10-18 16:59:46
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,6 +16,10 @@ from xml.etree import ElementTree
 import xml.etree.ElementTree as ET
 from urllib.parse import quote
 import hashlib
+from Crypto.PublicKey import RSA
+from Crypto.Signature import PKCS1_v1_5
+from Crypto.Hash import SHA256
+import string
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_framework.base_model import *
 from seven_cloudapp_frame.models.seven_model import InvokeResultData
@@ -28,7 +32,7 @@ class WeChatHelper:
     logger_error = Logger.get_logger_by_name("log_error")
 
     @classmethod
-    def code2_session(self, code, grant_type="authorization_code",app_id="", app_secret=""):
+    def code2_session(self, code, grant_type="authorization_code", app_id="", app_secret=""):
         """
         :description:临时登录凭证校验
         :param code：登录票据
@@ -158,14 +162,7 @@ class WeChatHelper:
         access_token = invoke_result_data.data
         try:
             requset_url = 'https://api.weixin.qq.com/cgi-bin/message/subscribe/send?access_token=' + access_token
-            param = {
-                "touser": open_id,
-                "page": page,
-                "lang": lang,
-                "data": request_data,
-                "template_id": template_id,
-                "miniprogram_state": miniprogram_state
-                }
+            param = {"touser": open_id, "page": page, "lang": lang, "data": request_data, "template_id": template_id, "miniprogram_state": miniprogram_state}
             response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers={'Content-Type': 'application/json'})
             response_data = SevenHelper.json_loads(response.text)
             if response_data.__contains__("errcode") and response_data["errcode"] != 0:
@@ -256,11 +253,11 @@ class WeChatHelper:
         if invoke_result_data.success == False:
             return invoke_result_data
         access_token = invoke_result_data.data
-        param = {"scene": scene, "page": page, "width": width, "auto_color": True, "is_hyaline": False}
         response = ""
         try:
             requset_url = 'https://api.weixin.qq.com/wxa/getwxacodeunlimit?access_token=' + access_token
             headers = {"Content-type": "application/json"}
+            param = {"scene": scene, "page": page, "width": width, "auto_color": True, "is_hyaline": False}
             response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers=headers)
             try:
                 response_data = SevenHelper.json_loads(response.text)
@@ -281,6 +278,52 @@ class WeChatHelper:
             invoke_result_data.error_message = traceback.format_exc()
             return invoke_result_data
 
+    @classmethod
+    def msg_sec_check(self, content, scene, open_id):
+        """
+        :description: 文本内容安全识别(https://developers.weixin.qq.com/miniprogram/dev/OpenApiDoc/sec-center/sec-check/msgSecCheck.html)
+        :param content：需检测的文本内容，文本字数的上限为2500字，需使用UTF-8编码
+        :param scene：场景枚举值（1 资料；2 评论；3 论坛；4 社交日志）
+        :param openid：用户的openid（用户需在近两小时访问过小程序）
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        invoke_result_data = InvokeResultData()
+        for i in range(2):
+            if i == 0:
+                invoke_result_data = self.get_access_token(app_id, app_secret)
+            else:
+                invoke_result_data = self.get_access_token(app_id, app_secret, True)
+
+            if invoke_result_data.success == True:
+                break
+        if invoke_result_data.success == False:
+            return invoke_result_data
+        access_token = invoke_result_data.data
+        response = ""
+        try:
+            requset_url = 'https://api.weixin.qq.com/wxa/msg_sec_check?access_token=' + access_token
+            headers = {"Content-type": "application/json"}
+            param = {"content": content, "scene": scene, "openid": open_id, "version": 2}
+            response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers=headers)
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data.__contains__("errcode") and response_data["errcode"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["errcode"]
+                invoke_result_data.error_message = response_data["errmsg"]
+                return invoke_result_data
+            invoke_result_data.data = response_data
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【msg_sec_check】" + traceback.format_exc() + ":" + str(response.text))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
     @classmethod
     def decrypt_data_by_code(self, open_id, code, encrypted_Data, iv, app_id="", app_secret=""):
         """
@@ -406,10 +449,29 @@ class WeChatHelper:
         sign = (hashlib.md5(string_sign_temp.encode("utf-8")).hexdigest()).upper()
         return sign
 
+    @classmethod
+    def signature_v3(self, private_key_path, sign_str):
+        """
+        :description:  生成V3签名值
+        :param private_key_path：私钥路径
+        :param sign_str：签名字符串
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        with open(private_key_path) as file:
+            private_key = file.read()
+        try:
+            rsa_key = RSA.import_key(private_key)
+            signer = PKCS1_v1_5.new(rsa_key)
+            digest = SHA256.new(sign_str.encode('utf-8'))
+            return base64.b64encode(signer.sign(digest)).decode('utf-8')
+        except Exception:
+            raise "WeixinPaySignIError"
+
 
 class WeChatPayRequest(object):
     """
-    :description: 微信支付请求类,配置文件内容 "wechat_pay": {"api_key": "","mch_id": "","certificate_url": "","certificate_key_url": ""}
+    :description: 微信支付请求类,配置文件内容 "wechat_pay": {"api_key": "","mch_id": "","certificate_url": "","private_key_url": ""}
     """
     """配置账号信息"""
     # =======【基本信息设置】=====================================
@@ -421,18 +483,18 @@ class WeChatPayRequest(object):
     api_key = ""
     # 证书地址,证书文件需要在商户后台下载
     certificate_url = ""
-    # 证书key地址
-    certificate_key_url = ""
+    # 商户私钥地址,文件需要在商户后台下载
+    private_key_url = ""
 
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self, app_id="", api_key="", mch_id="", certificate_url="", certificate_key_url=""):
+    def __init__(self, app_id="", api_key="", mch_id="", certificate_url="", private_key_url=""):
         pay_config = config.get_value("wechat_pay")
         self.app_id = app_id if app_id else config.get_value("app_id")
         self.api_key = api_key if api_key else pay_config["api_key"]
         self.mch_id = mch_id if mch_id else pay_config["mch_id"]
         self.certificate_url = certificate_url if certificate_url else pay_config["certificate_url"]
-        self.certificate_key_url = certificate_key_url if certificate_key_url else pay_config["certificate_key_url"]
+        self.private_key_url = private_key_url if private_key_url else pay_config.get("private_key_url", "")
 
     def get_prepay_id(self, unified_order_url, params):
         """
@@ -461,13 +523,13 @@ class WeChatPayRequest(object):
             else:
                 self.logger_error.error("【预支付单号】" + str(response_data))
                 invoke_result_data.success = False
-                invoke_result_data.error_code="error"
+                invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = response_data['err_code_des']
                 return invoke_result_data
         else:
             self.logger_error.error("【预支付单号】" + str(response_data))
             invoke_result_data.success = False
-            invoke_result_data.error_code="error"
+            invoke_result_data.error_code = "error"
             invoke_result_data.error_message = response_data['return_msg']
             return invoke_result_data
 
@@ -501,7 +563,7 @@ class WeChatPayRequest(object):
         if trade_type == "JSAPI":
             if open_id == "":
                 invoke_result_data.success = False
-                invoke_result_data.error_code="error"
+                invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = "缺少必填参数open_id"
                 return invoke_result_data
             else:
@@ -534,7 +596,7 @@ class WeChatPayRequest(object):
         invoke_result_data = InvokeResultData()
         if transaction_id == "" and pay_order_no == "":
             invoke_result_data.success = False
-            invoke_result_data.error_code="error"
+            invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "缺少必填参数transaction_id或pay_order_no"
             return invoke_result_data
         request_xml = ""
@@ -558,7 +620,7 @@ class WeChatPayRequest(object):
         except Exception as ex:
             self.logger_error.error("【查询订单】" + traceback.format_exc() + ":" + str(request_xml))
             invoke_result_data.success = False
-            invoke_result_data.error_code="error"
+            invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "查询订单出现异常"
             return invoke_result_data
 
@@ -572,17 +634,12 @@ class WeChatPayRequest(object):
         invoke_result_data = InvokeResultData()
         if pay_order_no == "":
             invoke_result_data.success = False
-            invoke_result_data.error_code="error"
+            invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "缺少必填参数pay_order_no"
             return invoke_result_data
         request_xml = ""
         try:
-            params = {
-                'appid': self.app_id,
-                'mch_id': self.mch_id,
-                'nonce_str': WeChatHelper.get_nonce_str(),
-                'out_trade_no': str(pay_order_no)
-            }
+            params = {'appid': self.app_id, 'mch_id': self.mch_id, 'nonce_str': WeChatHelper.get_nonce_str(), 'out_trade_no': str(pay_order_no)}
             params['sign'] = WeChatHelper.get_sign(params, self.api_key)
             request_xml = self.convert_request_xml(params)
             queryorder_url = 'https://api.mch.weixin.qq.com/pay/closeorder'
@@ -593,7 +650,7 @@ class WeChatPayRequest(object):
         except Exception as ex:
             self.logger_error.error("【关闭订单】" + traceback.format_exc() + ":" + str(request_xml))
             invoke_result_data.success = False
-            invoke_result_data.error_code="error"
+            invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "关闭订单出现异常"
             return invoke_result_data
 
@@ -653,13 +710,13 @@ class WeChatPayRequest(object):
             else:
                 self.logger_error.error("【创建退款单】" + str(response_data))
                 invoke_result_data.success = False
-                invoke_result_data.error_code="error"
+                invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = response_data['err_code_des']
                 return invoke_result_data
         else:
             self.logger_error.error("【创建退款单】" + str(response_data))
             invoke_result_data.success = False
-            invoke_result_data.error_code="error"
+            invoke_result_data.error_code = "error"
             invoke_result_data.error_message = response_data['return_msg']
             return invoke_result_data
 
@@ -673,18 +730,12 @@ class WeChatPayRequest(object):
         invoke_result_data = InvokeResultData()
         if refund_no == "":
             invoke_result_data.success = False
-            invoke_result_data.error_code="error"
+            invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "缺少必填参数refund_no"
             return invoke_result_data
         request_xml = ""
         try:
-            params = {
-                'appid': self.app_id,
-                'mch_id': self.mch_id,
-                'nonce_str': WeChatHelper.get_nonce_str(),
-                'out_refund_no': str(refund_no),
-                'sign_type': 'MD5'
-            }
+            params = {'appid': self.app_id, 'mch_id': self.mch_id, 'nonce_str': WeChatHelper.get_nonce_str(), 'out_refund_no': str(refund_no), 'sign_type': 'MD5'}
             params['sign'] = WeChatHelper.get_sign(params, self.api_key)
             request_xml = self.convert_request_xml(params)
             queryrefund_url = 'https://api.mch.weixin.qq.com/pay/refundquery'
@@ -695,7 +746,7 @@ class WeChatPayRequest(object):
         except Exception as ex:
             self.logger_error.error("【查询退款单】" + traceback.format_exc() + ":" + str(request_xml))
             invoke_result_data.success = False
-            invoke_result_data.error_code="error"
+            invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "查询退款单出现异常"
             return invoke_result_data
 
@@ -719,27 +770,14 @@ class WeChatPayRequest(object):
         client_ip = client_ip if SevenHelper.is_ip(client_ip) == True else "127.0.0.1"
         request_xml = ""
         try:
-            params = {
-                'appid': self.app_id,
-                'mch_id': self.mch_id,
-                'nonce_str': WeChatHelper.get_nonce_str(),
-                'mch_billno': str(mch_billno),
-                'send_name': send_name,
-                're_openid': re_openid,
-                'total_amount': total_amount,
-                'total_num': total_num,
-                'wishing': wishing,
-                'client_ip': client_ip,
-                'act_name': act_name,
-                'remark': remark
-            }
+            params = {'appid': self.app_id, 'mch_id': self.mch_id, 'nonce_str': WeChatHelper.get_nonce_str(), 'mch_billno': str(mch_billno), 'send_name': send_name, 're_openid': re_openid, 'total_amount': total_amount, 'total_num': total_num, 'wishing': wishing, 'client_ip': client_ip, 'act_name': act_name, 'remark': remark}
             if scene_id:
                 params['scene_id'] = scene_id
             params['sign'] = WeChatHelper.get_sign(params, self.api_key)
             request_xml = self.convert_request_xml(params)
             requset_url = 'https://api.mch.weixin.qq.com/mmpaymkttransfers/sendredpack'
-            # 重点是`cert=(certificate_url, certificate_key_url), verify=True`参数，查看源码后才知道是这样传ca证书
-            respone = requests.post(requset_url, data=request_xml, cert=(self.certificate_url, self.certificate_key_url), verify=True)
+            # 重点是`cert=(certificate_url, private_key_url), verify=True`参数，查看源码后才知道是这样传ca证书
+            respone = requests.post(requset_url, data=request_xml, cert=(self.certificate_url, self.private_key_url), verify=True)
             response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
             if response_data['return_code'] == 'SUCCESS':
                 if response_data['result_code'] == 'SUCCESS':
@@ -748,7 +786,7 @@ class WeChatPayRequest(object):
                 else:
                     self.logger_error.error("【发现金红包】" + str(response_data))
                     invoke_result_data.success = False
-                    invoke_result_data.error_code="error"
+                    invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = response_data['err_code_des']
                     return invoke_result_data
             invoke_result_data.data = response_data
@@ -760,7 +798,6 @@ class WeChatPayRequest(object):
             invoke_result_data.error_message = "发现金红包出现异常"
             return invoke_result_data
 
-
     def convert_request_xml(self, params):
         """
         :description:拼接XML
@@ -857,6 +894,7 @@ class WeChatDataCrypt:
     """
     :description: 微信数据解密帮助类
     """
+
     def __init__(self, app_id, session_key):
         self.app_id = app_id
         self.session_key = session_key
@@ -877,4 +915,230 @@ class WeChatDataCrypt:
         return decrypted
 
     def _unpad(self, s):
-        return s[:-ord(s[len(s) - 1:])]
\ No newline at end of file
+        return s[:-ord(s[len(s) - 1:])]
+
+
+class WeChatPayV3Request(object):
+    """
+    微信V3支付支付
+    """
+    # 微信公众号身份的唯一标识。审核通过后，在微信发送的邮件中查看
+    app_id = ""
+    # 商户ID，身份标识
+    mch_id = ""
+    # API密钥，需要在商户后台设置
+    api_key = ""
+    # 证书地址,证书文件需要在商户后台下载
+    certificate_url = ""
+    # 商户私钥地址apiclient_key.pem 地址,文件需要在商户后台下载
+    private_key_url = ""
+    # 商户API证书序列号
+    mch_serial_no = ""
+
+    logger_error = Logger.get_logger_by_name("log_error")
+
+    base_url = 'https://api.mch.weixin.qq.com'
+
+    def __init__(self, app_id="", api_key="", mch_id="", mch_serial_no="", certificate_url="", private_key_url=""):
+
+        pay_config = config.get_value("wechat_pay", {})
+        self.app_id = app_id if app_id else config.get_value("app_id")
+        self.mch_id = mch_id if mch_id else pay_config.get("mch_id", "")
+        self.api_key = api_key if api_key else pay_config.get("api_key", "")
+        self.mch_serial_no = mch_serial_no if mch_serial_no else pay_config.get("mch_serial_no", "")
+        self.certificate_url = certificate_url if certificate_url else pay_config.get("certificate_url", "")
+        self.private_key_url = private_key_url if private_key_url else pay_config.get("private_key_url", "")
+        self.timestamp = str(int(time.time()))
+        self.nonce_str = ''.join(random.sample(string.ascii_letters + string.digits, 16))
+
+    def _generate_request_sign(self, url_path, data, method='POST'):
+        """
+        :description:  生成请求签名
+        :param url_path：不包含域名的请求地址
+        :param data：请求参数（post请求才需要传,get传None）
+        :param method：请求方式
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        sign_list = [method, url_path, self.timestamp, self.nonce_str]
+        if data is not None:
+            sign_list.append(data)
+        else:
+            sign_list.append('')
+        sign_str = '\n'.join(sign_list) + '\n'
+        return WeChatHelper.signature_v3(private_key_path=self.private_key_url, sign_str=sign_str)
+
+    def _generate_pay_sign(self, app_id, package):
+        """
+        :description:  生成支付签名
+        :param app_id：商户绑定的应用标识
+        :param package：订单详情扩展字符串（示例值：prepay_id=wx201410272009395522657a690389285100）
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        sign_list = [app_id, self.timestamp, self.nonce_str, package]
+        sign_str = '\n'.join(sign_list) + '\n'
+        return WeChatHelper.signature_v3(private_key_path=self.cert_dir, sign_str=sign_str)
+
+    def _generate_auth_header(self, signature):
+        """
+        生成授权请求头
+        """
+        return f'WECHATPAY2-SHA256-RSA2048 mchid="{self.mch_id}",nonce_str="{self.nonce_str}",' \
+               f'signature="{signature}",timestamp="{self.timestamp}",serial_no="{self.mch_serial_no}"'
+
+    def transfer_one(self, open_id, out_batch_no, batch_name, batch_remark, total_amount):
+        """
+        :description:  单次商家转账
+        :param open_id：open_id是微信用户在公众号appid下的唯一用户标识（appid不同，则获取到的openid就不同），可用于永久标记一个用户
+        :param out_batch_no：商家批次单号（商户生成的唯一编号）
+        :param batch_name：批次名称
+        :param batch_remark：批次备注
+        :param total_amount：转账总金额(单位：分)
+        :return: 错误码返回SYSTEM_ERROR和NOT_ENOUGH和FREQUENCY_LIMITED 请勿更换商家转账批次单号，请使用相同参数再次调用API。否则可能造成资金损失
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        url_path = '/v3/transfer/batches'
+        url = self.base_url + url_path
+        transfer_detail_list = []
+        transfer_detail = {}
+        transfer_detail["out_detail_no"] = out_batch_no
+        transfer_detail["transfer_amount"] = total_amount
+        transfer_detail["transfer_remark"] = batch_remark
+        transfer_detail["openid"] = open_id
+        transfer_detail_list.append(transfer_detail)
+
+        data = {'appid': self.app_id, 'out_batch_no': out_batch_no, "batch_name": batch_name, "batch_remark": batch_remark, "total_amount": total_amount, 'total_num': 1, "transfer_detail_list": transfer_detail_list}
+
+        try:
+            data = json.dumps(data)
+            signature = self._generate_request_sign(url_path=url_path, data=data)
+            # print("Authorization signature:", self._generate_auth_header(signature))
+            headers = {'Authorization': self._generate_auth_header(signature), 'Content-Type': 'application/json'}
+            res = requests.post(url=url, data=data, headers=headers, timeout=10)
+            response_data = SevenHelper.json_loads(res.text)
+            if response_data.__contains__("code") and response_data["code"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["code"]
+                invoke_result_data.error_message = response_data["message"]
+                return invoke_result_data
+            invoke_result_data.data = response_data
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【v3_transfer_one】" + traceback.format_exc())
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
+    def transfer_list(self, out_batch_no, batch_name, batch_remark, total_amount, total_num, transfer_detail_list=[]):
+        """
+        :description:  批量商家转账
+        :param out_batch_no：商家批次单号（商户生成的唯一编号）
+        :param batch_name：批次名称
+        :param batch_remark：批次备注
+        :param total_amount：转账总金额
+        :param total_num：转账总笔数
+        :param transfer_detail_list：转账明细列表
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        url_path = '/v3/transfer/batches'
+        url = self.base_url + url_path
+        data = {'appid': self.app_id, 'out_batch_no': out_batch_no, "batch_name": batch_name, "batch_remark": batch_remark, "total_amount": total_amount, 'total_num': total_num, "transfer_detail_list": transfer_detail_list}
+
+        try:
+            data = json.dumps(data)
+            signature = self._generate_request_sign(url_path=url_path, data=data)
+            # print("Authorization signature:", self._generate_auth_header(signature))
+            headers = {'Authorization': self._generate_auth_header(signature), 'Content-Type': 'application/json'}
+            res = requests.post(url=url, data=data, headers=headers, timeout=10)
+            response_data = SevenHelper.json_loads(res.text)
+            if response_data.__contains__("code") and response_data["code"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["code"]
+                invoke_result_data.error_message = response_data["message"]
+                return invoke_result_data
+            invoke_result_data.data = response_data
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【v3_transfer_list】" + traceback.format_exc())
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
+    def query_batches(self, batch_id, need_query_detail=False, offset=0, limit=20, detail_status=None):
+        """
+        :description:  商家转账批次单号查询批次单
+        :param batch_id：微信批次单号
+        :param need_query_detail：是否查询转账明细单(枚举值：true：是；false：否，默认否。商户可选择是否查询指定状态的转账明细单，当转账批次单状态为“FINISHED”（已完成）时，才会返回满足条件的转账明细单)
+        :param offset：请求资源起始位置
+        :param limit：最大资源条数
+        :param detail_status：明细状态(查询指定状态的转账明细单，当need_query_detail为true时，该字段必填ALL:全部。需要同时查询转账成功和转账失败的明细单SUCCESS:转账成功。只查询转账成功的明细单FAIL:转账失败。只查询转账失败的明细单)
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        url_path = f'/v3/transfer/batches/batch-id/{batch_id}'
+        data = {'need_query_detail': need_query_detail, 'offset': offset, 'limit': limit}
+        if need_query_detail == True:
+            detail_status = "ALL"
+        if detail_status:
+            data["detail_status"] = detail_status
+        url_path = url_path + "?" + WeChatHelper.key_value_url(data, False)
+        url = self.base_url + url_path
+        data = None
+        try:
+            signature = self._generate_request_sign(url_path=url_path, data=data, method='GET')
+            # print("Authorization signature:", self._generate_auth_header(signature))
+            headers = {'Authorization': self._generate_auth_header(signature), 'Content-Type': 'application/json'}
+            res = requests.get(url=url, data=data, headers=headers, timeout=10)
+            response_data = SevenHelper.json_loads(res.text)
+            if response_data.__contains__("code") and response_data["code"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["code"]
+                invoke_result_data.error_message = response_data["message"]
+                return invoke_result_data
+            invoke_result_data.data = response_data
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【v3_query_batches】" + traceback.format_exc())
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
+    def query_batches_detail(self, batch_id, detail_id):
+        """
+        :description:  微信明细单号查询明细单
+        :param batch_id：微信批次单号
+        :param detail_id：微信明细单号
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        url_path = f'/v3/transfer/batches/batch-id/{batch_id}/details/detail-id/{detail_id}'
+        url = self.base_url + url_path
+        data = None
+        try:
+            signature = self._generate_request_sign(url_path=url_path, data=data, method='GET')
+            # print("Authorization signature:", self._generate_auth_header(signature))
+            headers = {'Authorization': self._generate_auth_header(signature), 'Content-Type': 'application/json'}
+            res = requests.get(url=url, data=data, headers=headers, timeout=10)
+            response_data = SevenHelper.json_loads(res.text)
+            if response_data.__contains__("code") and response_data["code"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["code"]
+                invoke_result_data.error_message = response_data["message"]
+                return invoke_result_data
+            invoke_result_data.data = response_data
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【v3_query_batches_detail】" + traceback.format_exc())
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
