@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2022-09-27 09:09:42
+@LastEditTime: 2022-09-28 11:55:20
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -275,20 +275,23 @@ class AppBaseModel():
         live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"
         return live_url
 
-    def _delete_dict_info_dependency_key(self, parent_id, delay_delete_time=0.01):
+    def _delete_dict_info_dependency_key(self, parent_id, dict_type, delay_delete_time=0.01):
         """
         :description: 删除字典信息依赖建
         :param parent_id: 父节点标识
+        :param dict_type: 字典类型
         :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
         :last_editors: HuangJianYi
         """
-        CmsDictInfoModel().delete_dependency_key(DependencyKey.dict_info_list(parent_id), delay_delete_time)
+        DictInfoModel().delete_dependency_key(DependencyKey.dict_info_list(parent_id, dict_type), delay_delete_time)
 
-    def save_dict_info(self, parent_id, dict_id, dict_name, dict_value, dict_pic, sort_index, is_release, i1, i2, s1, s2):
+    def save_dict_info(self, dict_id, parent_id, dict_type, dict_name, dict_value, dict_pic, sort_index, is_release, i1, i2, s1, s2):
         """
         :description: 保存字典
+        :param dict_id: 字典标识
         :param parent_id: 父节点标识
+        :param dict_type: 字典类型
         :param dict_name：字典名称
         :param dict_value：字典值
         :param dict_pic：字典图片
@@ -302,7 +305,7 @@ class AppBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not parent_id or not dict_name:
+        if (not parent_id and not dict_type) or not dict_name:
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
@@ -323,6 +326,7 @@ class AppBaseModel():
             is_add = True
             dict_info = DictInfo()
         dict_info.parent_id = parent_id
+        dict_info.dict_type = dict_type
         dict_info.dict_name = dict_name
         dict_info.dict_value = dict_value
         dict_info.dict_pic = dict_pic
@@ -343,13 +347,14 @@ class AppBaseModel():
         result["new"] = dict_info
         result["old"] = old_dict_info
         invoke_result_data.data = result
-        self._delete_dict_info_dependency_key(parent_id)
+        self._delete_dict_info_dependency_key(parent_id, dict_type)
         return invoke_result_data
 
-    def get_dict_info_list(self, parent_id, page_size, page_index, order_by="id desc",field="*", is_cache=True):
+    def get_dict_info_list(self, parent_id, dict_type, page_size, page_index, order_by="id desc",field="*", is_cache=True):
         """
         :description: 字典列表
         :param parent_id：父节点标识
+        :param dict_type: 字典类型
         :param page_size：页大小
         :param page_index：页索引
         :param order_by：排序
@@ -360,13 +365,21 @@ class AppBaseModel():
         """
         page_list = []
         total = 0
-        if not parent_id:
+        if not parent_id or not dict_type:
             return page_list, total
-        condition = "parent_id=%s and is_release=1"
-        params = [parent_id]
+        condition_where = ConditionWhere()
+        params = []
+        if parent_id:
+            condition_where.add_condition("parent_id=%s")
+            params.append(parent_id)
+        if dict_type:
+            condition_where.add_condition("dict_type=%s")
+            params.append(dict_type)
+        condition_where.add_condition("is_release=1")
+
         dict_info_model = DictInfoModel(context=self.context)
         if is_cache == True:
-            page_list, total = dict_info_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=DependencyKey.dict_info_list(parent_id),cache_expire=600)
+            page_list, total = dict_info_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by,params=params,dependency_key=DependencyKey.dict_info_list(parent_id,dict_type),cache_expire=600)
         else:
-            page_list, total = dict_info_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
+            page_list, total = dict_info_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by,params=params)
         return page_list, total
\ No newline at end of file
