@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-06-02 14:32:40
-@LastEditTime: 2022-06-30 14:42:56
+@LastEditTime: 2022-10-13 13:45:18
 @LastEditors: HuangJianYi
 :description: 枚举类
 """
@@ -16,10 +16,15 @@ class OperationType(Enum):
     :description: 用户操作日志类型
     """
     add = 1 #添加
-    update = 2 #更新
+    update = 2 #编辑
     delete = 3 #删除
     review = 4 #还原
     copy = 5 #复制
+    export = 6 #导出
+    import_data = 7 #导入
+    release = 8 #上架
+    un_release = 9 #下架
+    operate = 10 #操作
 
 @unique
 class TaskType(Enum):
