@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-12-20 16:07:52
-@LastEditTime: 2022-06-12 14:07:00
+@LastEditTime: 2022-09-26 14:17:36
 @LastEditors: HuangJianYi
 @Description: 中台接口相关处理业务模型
 """
@@ -32,6 +32,9 @@ class MPBaseModel():
             return public_function_list
         #产品id
         product_id = config.get_value("project_name")
+        power_project_id = config.get_value("power_project_id") # 权限产品id,SaaS走project_name,SaaS定制走power_project_id
+        if power_project_id:
+            product_id = power_project_id
         if not product_id:
             return public_function_list
         requst_url = config.get_value("mp_url","http://taobao-mp-s.gao7.com") + "/general/project_code_list"
@@ -54,6 +57,9 @@ class MPBaseModel():
         custom_function_list = []
         #产品id
         product_id = config.get_value("project_name")
+        power_project_id = config.get_value("power_project_id") # 权限产品id,SaaS走project_name,SaaS定制走power_project_id
+        if power_project_id:
+            product_id = power_project_id
         if not product_id:
             return custom_function_list
         requst_url = config.get_value("mp_url", "http://taobao-mp-s.gao7.com") + "/custom/query_skin_managemen_list"
