@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-08-16 14:13:05
+@LastEditTime: 2022-10-17 16:19:57
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -381,7 +381,7 @@ class UserBaseModel(FrameBaseModel):
         user_info_model.update_entity(user_info, "user_state,relieve_date,modify_date")
 
         self._delete_user_info_cache(user_info.act_id, user_info.id_md5)
-
+        invoke_result_data.data = user_info.__dict__
         return invoke_result_data
 
     def update_user_state_by_black(self, app_id, act_id, user_id, reason=""):
@@ -458,7 +458,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"
-
+        invoke_result_data.data = user_info_dict
         return invoke_result_data
 
     def apply_black_unbind(self, app_id, act_id, user_id, open_id="", reason="误封号,申请解封"):
@@ -593,19 +593,20 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
         user_black_model = UserBlackModel(context=self.context)
-        black_info = user_black_model.get_entity_by_id(black_id)
-        if not black_info:
+        user_black = user_black_model.get_entity_by_id(black_id)
+        if not user_black:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "找不到该条记录"
             return invoke_result_data
-        if black_info.app_id != app_id:
+        if user_black.app_id != app_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
             return invoke_result_data
         user_black_model.update_table("audit_remark=%s", "id=%s", [audit_remark, black_id])
-        self._delete_user_black_cache(black_info.act_id, black_info.user_id)
+        self._delete_user_black_cache(user_black.act_id, user_black.user_id)
+        invoke_result_data.data = {"user_black": user_black.__dict__}
         return invoke_result_data
 
     def get_black_info_dict(self, app_id, act_id, user_id, is_cache=True):
